import xbmc
import xbmcaddon
import RPi.GPIO as GPIO

# DEFINITIONS

LEDS = {'LED_PAUSE': 18, 'LED_PLAY': 14, 'LED_RECORD': 15}
'''
    Pinout see https://pinout.xyz/pinout/ground#:~:text=The%20Ground%20pins%20on%20the,supply%20pin%20that%20you%20use
    
    LED_PAUSE      # Pin 12
    LED_PLAY       # Pin 8
    LED_RECORD     # Pin 10
'''

LED_ACTIVE = True       # False: Pull Down (Sink) as active state, True: (Source 3.3V) as active state

addon = xbmcaddon.Addon()
addon_id = addon.getAddonInfo('id')
addon_version = addon.getAddonInfo('version')

def log(msg, level=xbmc.LOGINFO):
    xbmc.log('[%s %s] %s' % (addon_id, addon_version, msg), level=level)


class LedSwitch(object):
    def __init__(self):
        GPIO.setmode(GPIO.BCM)
        GPIO.setwarnings(False)
        for LED in LEDS.values(): GPIO.setup(LED, GPIO.OUT, initial= not LED_ACTIVE)
        log('GPIO pins initialized')

    def switch_led(self, GPIOleds, onoff=LED_ACTIVE):
        '''
            switch LED on or off
            Parameters: array GPIOleds, bool state [Name of LED, (not) LED_ACTIVE]
        '''
        for led in GPIOleds: GPIO.output(LEDS[led], onoff)


class EventLogger(xbmc.Monitor):
    def __init__(self):
        xbmc.Monitor.__init__(self)
        self.RpiLeds = LedSwitch()
        log('Event logger started')

    def onNotification(self, sender, method, data):
        log('Event notified: %s, sender: %s, data: %s' % (method, sender, data))
        if method == 'Player.OnPlay': self.RpiLeds.switch_led(['LED_PLAY'], LED_ACTIVE)
        elif method == 'Player.OnPause': self.RpiLeds.switch_led(['LED_PAUSE'], LED_ACTIVE)
        elif method == 'Player.OnResume': self.RpiLeds.switch_led(['LED_PAUSE'], not LED_ACTIVE)
        elif method == 'Player.OnStop': self.RpiLeds.switch_led(['LED_PLAY', 'LED_PAUSE'], not LED_ACTIVE)
        else: log('Event discarded')

    def logEvents(self):
        while not self.abortRequested(): self.waitForAbort(1000)


if __name__ == '__main__':
    Logger = EventLogger()
    Logger.logEvents()
    log('Event logger stopped')
    del Logger
